@@ -51,7 +51,6 @@ NULL
 #' Erdos, Paul, and Alfred Renyi. 1959. 
 #' "\href{https://www.renyi.hu/~p_erdos/1959-11.pdf}{On Random Graphs I}" 
 #' _Publicationes Mathematicae_. 6: 290–297.
-#' @importFrom igraph sample_bipartite sample_gnp sample_gnm
 #' @examples
 #' generate_random(12, 0.4)
 #' # generate_random(c(6, 6), 0.4)
@@ -61,11 +60,19 @@ generate_random <- function(n, p = 0.5, directed = FALSE, with_attr = TRUE) {
     m <- net_ties(n)
     directed <- is_directed(n)
     if(is_twomode(n)){
-      g <- igraph::sample_bipartite(net_dims(n)[1], 
-                                    net_dims(n)[2],
-                                    m = m, type = "gnm",
-                                    directed = directed,
-                                    mode = "out")
+      if (utils::packageVersion("igraph") >= "2.2.0") {
+        g <- igraph::sample_bipartite_gnm(net_dims(n)[1],
+                                          net_dims(n)[2],
+                                          m = m,
+                                          directed = directed,
+                                          mode = "out")
+      } else {
+        g <- igraph::sample_bipartite(net_dims(n)[1], 
+                                      net_dims(n)[2],
+                                      m = m, type = "gnm",
+                                      directed = directed,
+                                      mode = "out")
+      }
     } else {
       g <- igraph::sample_gnm(net_nodes(n), 
                               m = m,
@@ -82,11 +89,24 @@ generate_random <- function(n, p = 0.5, directed = FALSE, with_attr = TRUE) {
   } else if (length(n) == 2) {
     if(p > 1){
       if(!as.integer(p)==p) snet_abort("`p` must be an integer if above 1.")
-      g <- igraph::sample_bipartite(n[1], n[2],
-                                    m = p,
-                                    type = "gnm",
-                                    directed = directed,
-                                    mode = "out")
+      if (utils::packageVersion("igraph") >= "2.2.0") {
+        g <- igraph::sample_bipartite_gnm(n[1], n[2],
+                                          m = p,
+                                          directed = directed,
+                                          mode = "out")
+      } else {
+        g <- igraph::sample_bipartite(n[1], n[2],
+                                      m = p,
+                                      type = "gnm",
+                                      directed = directed,
+                                      mode = "out")
+    }
+  } else {
+    if (utils::packageVersion("igraph") >= "2.2.0") {
+      g <- igraph::sample_bipartite_gnp(n[1], n[2],
+                                        p = p,
+                                        directed = directed,
+                                        mode = "out")
     } else {
       g <- igraph::sample_bipartite(n[1], n[2],
                                     p = p,
@@ -94,6 +114,7 @@ generate_random <- function(n, p = 0.5, directed = FALSE, with_attr = TRUE) {
                                     directed = directed,
                                     mode = "out")
     }
+    }
     
   } else {
     snet_abort("`n` must be of length=1 for a one-mode network or length=2 for a two-mode network.")
