@@ -4,9 +4,9 @@
 #'
 #' @description 
 #'   Researchers regularly need to work with a variety of external data formats.
-#'   The following functions offer ways to import from some common external
-#'   file formats into objects that `{manynet}` and other graph/network packages
-#'   in R can work with:
+#'   The following functions enable importing from some common external file 
+#'   formats into objects that `{manynet}` and other graph/network packages in R 
+#'   can work with:
 #' 
 #'   - `read_matrix()` imports adjacency matrices from Excel/csv files.
 #'   - `read_edgelist()` imports edgelists from Excel/csv files.
@@ -15,6 +15,8 @@
 #'   - `read_ucinet()` imports UCINET files from the header (.##h).
 #'   - `read_dynetml()` imports DyNetML interchange format for rich social network data.
 #'   - `read_graphml()` imports GraphML files.
+#'   - `read_gml()` imports GML files.
+#'   - `read_gdf()` imports GDF files.
 #' @details
 #'   Note that these functions are not as actively maintained as others
 #'   in the package, so please let us know if any are not currently working
@@ -411,6 +413,75 @@ read_gml <- function(file = file.choose()) {
   as_tidygraph(igraph::read_graph(file, format = "gml"))
 }
 
+#' @rdname make_read
+#' @export
+read_gdf <- function(file = file.choose()) {
+  if(missing(file)) cli::cli_alert_success("Executing: read_gdf('{file}')")
+  gdf <- readLines(file)
+  
+  edge_place <- grep("edgedef>", gdf)
+  if (length(edge_place) > 0) {
+    has_edge_data <- length(length(edge_place):length(gdf)) > 1
+    node_data <- gdf[1:(edge_place - 1)]
+  } else {
+    has_edge_data <- FALSE
+    node_data <- gdf
+  }
+  
+  if (has_edge_data) {
+    snet_minor_info("Extracting tie data.")
+    edge_data <- gdf[edge_place:length(gdf)]
+    edge_data[1] <- sub("edgedef>node", "node", edge_data[1])
+    edge_data <- read.table(text = edge_data, sep = ",", 
+                            header = TRUE, stringsAsFactors = FALSE)
+    if(is.numeric(edge_data[,1])) edge_data[,1] <- as.character(edge_data[,1])
+    if(is.numeric(edge_data[,2])) edge_data[,2] <- as.character(edge_data[,2])
+    names(edge_data) <- c("from","to")
+  } else {
+    snet_minor_info("No tie data found.")
+    edge_data <- data.frame()
+  }
+  
+  snet_minor_info("Extracting node data")
+  node_data[1] <- gsub("nodedef>name", "name", node_data[1])
+  node_data[1] <- paste0(
+    sapply(strsplit(node_data[1], ","),
+           function(x) gsub("^(.*) [A-Z]+$", "\\1", x)),
+    collapse = ","
+  )
+  
+  ## Some links have commas in them without quotation marks, thus messing
+  ## up the fread. We just remove troubled rows, and check n commas in
+  ## the header row
+  n_sep <- lengths(regmatches(node_data, gregexpr(",", node_data)))
+  bad_apples <- which(n_sep != stats::median(n_sep[2:length(n_sep)]))
+  bad_apples <- bad_apples[bad_apples != 1]
+  if (length(bad_apples) > 0) {
+    node_data <- node_data[-bad_apples]
+    snet_minor_info("Removed {length(bad_apples)} row{?s} due to comma errors.")
+  }
+  if (n_sep[1] < stats::median(n_sep)) {
+    node_data[1] <- paste0(
+      node_data[1],
+      paste0(rep(",", (stats::median(n_sep[2:length(n_sep)]) - n_sep[1])),
+             collapse = "")
+    )
+  }
+  
+  ## The combine and fread, if there is any node data.
+  if (length(node_data) > 1) {
+    node_data <- data.frame(do.call(rbind, strsplit(node_data, ",")))
+    names(node_data) <- node_data[1,]
+    node_data <- node_data[-1, ]
+  } else {
+    snet_minor_info("No node data found.")
+    node_data <- data.frame()
+    has_node_data <- FALSE
+  }
+  
+  as_tidygraph(list(nodes = node_data, ties = edge_data))
+}
+
 # Write ####
 
 #' Making networks to external files
@@ -677,33 +748,42 @@ write_graphml <- function(.data,
 
 # Dependencies ####
 
-#' Making networks of package dependencies
+#' Making networks of inter- and intra-package dependencies
 #'
-#' @description 
-#'   Researchers regularly need to work with a variety of external data formats.
-#'   The following functions offer ways to import from some common external
-#'   file formats into objects that `{manynet}` and other graph/network packages
-#'   in R can work with:
-#' 
-#'   - `read_matrix()` imports adjacency matrices from Excel/csv files.
-#'   - `read_edgelist()` imports edgelists from Excel/csv files.
-#'   - `read_nodelist()` imports nodelists from Excel/csv files.
-#'   - `read_pajek()` imports Pajek (.net or .paj) files.
-#'   - `read_ucinet()` imports UCINET files from the header (.##h).
-#'   - `read_dynetml()` imports DyNetML interchange format for rich social network data.
-#'   - `read_graphml()` imports GraphML files.
+#' @description
+#' These functions read information from CRAN or within an R package's
+#' working directory to create a networks of a package's dependencies:
+#'
+#' - `read_cran()` creates a network of a package's dependencies on other
+#'    packages available on CRAN.
+#'    It looks for the `Depends`, `Imports` and `Suggests` fields
+#'    in the package's DESCRIPTION file
+#'    and creates a network where nodes are packages
+#'    and ties are dependencies.
+#' - `read_pkg()` creates a network of function dependencies
+#'    from R scripts in a directory.
+#'    It looks for function definitions and function calls
+#'    within the scripts and creates a network
+#'    where nodes are functions and edges are function calls.
+#'    It can also include function calls
+#'    to functions not defined within the scripts.
 #' @details
 #'   Note that these functions are not as actively maintained as others
 #'   in the package, so please let us know if any are not currently working
 #'   for you or if there are missing import routines 
 #'   by [raising an issue on Github](https://github.com/stocnet/manynet/issues).
 #' @param pkg The name 
+#' @return A `tidygraph` object representing the network of package dependencies
+#'   or function dependencies in a package.
 #' @source 
 #' https://www.r-bloggers.com/2016/01/r-graph-objects-igraph-vs-network/
 #' @importFrom utils available.packages contrib.url
 #' @name make_cran
 #' @family makes
 #' @seealso [as]
+NULL
+
+#' @rdname make_cran
 #' @examples
 #' # mnet <- read_cran()
 #' # mnet <- to_ego(mnet, "manynet", max_dist = 2)
@@ -754,4 +834,456 @@ read_cran <- function(pkg = "all"){
   out
 }
 
+#' @rdname make_cran
+#' @importFrom dplyr bind_rows mutate filter select everything
+#' @importFrom igraph graph_from_data_frame
+#' @param dir Character string or vector of character strings
+#'   with the directory or directories to search for R scripts.
+#'   If `NULL` (the default), the current working directory is used.
+#' @author Jakob Gepp
+#' @source https://github.com/STATWORX/helfRlein/blob/master/R/get_network.R
+#' @examples
+#' # mnet <- read_pkg()
+#' @export
+read_pkg <- function(dir = getwd()) {
+  
+  variations = c("<- function",
+                 " <- function",
+                 "<-function",
+                 " <-function")
+  
+  # check if dir exists
+  if(!grepl(".*R$", dir)){
+    dir <- paste0(dir, "/R")
+  }
+  if (!is.null(dir) && all(!dir.exists(dir))) {
+    stop(paste0(dir, " does not exists"))
+  }
+  
+  # get files and folder within dir
+  files_path <- list.files(file.path(dir),
+                           pattern = "\\.R$",
+                           recursive = TRUE,
+                           full.names = TRUE)
+  files_path <- files_path[!grepl("testthat", files_path)]
+  files_path <- files_path[!grepl("zzz", files_path)]
+  files_path <- files_path[!grepl("defunct", files_path)]
+  if (length(files_path) == 0) {
+    snet_abort("No files with the given pattern")
+  }
+  
+  # common_base_path <- function(paths) {
+  #   # Split each path into its components
+  #   split_paths <- strsplit(paths, "/")
+  #   
+  #   # Find the common path
+  #   common_path <- Reduce(function(x, y) {
+  #     # Get the length of the shorter vector
+  #     min_length <- min(length(x), length(y))
+  #     # Only compare the elements up to the length of the shorter vector
+  #     common <- x[seq_len(min_length)] == y[seq_len(min_length)]
+  #     # If there's a FALSE in common, only keep the elements before it
+  #     if (any(!common)) x[seq_len(which(!common)[1] - 1)]
+  #     else x
+  #   }, split_paths)
+  #   
+  #   # Combine the common path components back into a single string
+  #   common_path <- paste(common_path, collapse = "/")
+  #   
+  #   return(common_path)
+  # }
+  # 
+  # dir_base <- common_base_path(paths = dir)
+  # folder <- dirname(gsub(paste0(dir_base, "/"), "", files_path))
+  folder <- paste0(dirname(files_path)[1], "/")
+  
+  # Get all scripts ####
+  all_scripts <- lapply(files_path, readLines, warn = FALSE)
+  # set names of scripts
+  names(all_scripts) <- gsub("\\.R$", "", basename(files_path))
+  snet_minor_info("Found {length(all_scripts)} scripts")
 
+  # Check for empty scripts ####
+  indx <- sapply(all_scripts, length) == 0
+  if (any(indx)) {
+    warning(paste0("Removing empty scripts: ",
+                   paste0(names(all_scripts)[indx], collapse = ", ")))
+    all_scripts <- all_scripts[!indx]
+    folder <- folder[!indx]
+  }
+  
+  # remove variations with "
+  # this is done so that strings like "<- function" will not be counted
+  for (i_var in variations) {
+    all_scripts <- lapply(all_scripts,
+                          function(x) gsub(paste0("\"", i_var), "", x))
+  }
+  
+  # remove method / functions that start with [
+  # otherwise the regular expression will be messed up later
+  keep <- !startsWith(names(all_scripts), "[")
+  snet_minor_info("Removing {sum(!keep)} scripts that start with [")
+  all_scripts <- all_scripts[keep]
+  # folder <- folder[keep]
+  
+  # remove leading spaces
+  all_scripts <- lapply(all_scripts, function(x)  sub("^\\s+", "", x))
+  
+  # split before #
+  # all_scripts <- lapply(all_scripts, 
+  #                       function(x) unlist(strsplit(x = x, split = "#")[1]))
+  # remove comments #
+  all_scripts <- lapply(all_scripts, function(x) subset(x, !startsWith(x, "#")))
+  
+  # check for empty scripts
+  indx <- sapply(all_scripts, length) == 0
+  if (any(indx)) {
+    warning(paste0("Removing empty scripts: ",
+                   paste0(names(all_scripts)[indx], collapse = ", ")))
+    all_scripts <- all_scripts[!indx]
+    folder <- folder[!indx]
+  }
+  
+  # # split before { and }
+  # all_scripts <- lapply(all_scripts,
+  #                       function(x) unlist(strsplit(x = x, split = "[\\{\\}]")[1]))
+  # # split after { and }
+  # all_scripts <- lapply(all_scripts,
+  #                       function(x) unlist(strsplit(x = x, split = "[\\{\\}]")[2]))
+  
+  # remove leading spaces again
+  all_scripts <- lapply(all_scripts, function(x)  sub("^\\s+", "", x))
+  
+  # remove empty lines
+  all_scripts <- lapply(all_scripts, function(x) x[x != ""])
+  
+  # check for empty scripts
+  indx <- sapply(all_scripts, length) == 0
+  if (any(indx)) {
+    warning(paste0("Removing empty scripts: ",
+                   paste0(names(all_scripts)[indx], collapse = ", ")))
+    all_scripts <- all_scripts[!indx]
+    folder <- folder[!indx]
+  }
+  
+  # filter only those with functions (variations) in it
+  index_functions <- unique(unlist(sapply(variations, grep, all_scripts)))
+  main_functions  <- all_scripts[index_functions]
+  # folder_main     <- folder[index_functions]
+  scripts         <- all_scripts[-index_functions]
+  # folder_scripts  <- folder[-index_functions]
+  
+  snet_minor_info("Found {length(index_functions)} scripts containing function definitions")
+  
+  # get subfunctions
+  getsubindex <- function(funlist,
+                          variations) {
+    def_function_index <-
+      lapply(funlist,
+             function(x) {
+               sort(unique(unlist(
+                 lapply(variations,
+                        function(y) which(grepl(pattern = y, x))))
+               ))
+             }
+      )
+    
+    # get internal functions
+    with_internal <- which(sapply(def_function_index, length) > 1)
+    internal <- funlist[with_internal]
+    def_internal <- lapply(def_function_index[with_internal],
+                           function(x) sort(x))
+    
+    open  <- lapply(internal, function(x) as.numeric(grepl("\\{", x)))
+    close <- lapply(internal, function(x) as.numeric(grepl("\\}", x)))
+    both <- mapply(function(x, y) cumsum(x - y), open, close, SIMPLIFY = FALSE)
+    
+    sub_index_end <- mapply(function(x, z) {
+      sapply(z, function(y) {
+        tmp <- which(x == x[y])
+        tmp <- tmp[tmp > y]
+        if (length(tmp) == 1) {
+          tmp
+        } else {
+          if (all(diff(tmp) == 1)) {
+            suppressWarnings(min(tmp, na.rm = TRUE))
+          } else {
+            suppressWarnings(min(tmp[c(diff(c(y, tmp)) > 1)], na.rm = TRUE))
+          }
+        }
+      })},
+      both, def_internal, SIMPLIFY = FALSE)
+    
+    
+    # set Inf to max length
+    max_length <- lapply(internal, length)
+    sub_index_end <- mapply(function(x, y) ifelse(x == Inf, y, x),
+                            sub_index_end, max_length, SIMPLIFY = FALSE)
+    
+    sub_index <- mapply(function(x, y) cbind(x, y),
+                        def_internal, sub_index_end, SIMPLIFY = FALSE)
+    
+    # remove row if it is from first to last
+    sub_index <- mapply(
+      function(x, y) matrix(x[!apply(x, 1, diff) >= c(y - 2), ], ncol = 2),
+      sub_index, max_length, SIMPLIFY = FALSE)
+    
+    out <- list()
+    out$sub_index <- sub_index
+    out$internal <- internal
+    
+    return(out)
+  }
+  
+  tmp <- getsubindex(funlist = main_functions,
+                     variations = variations)
+  sub_index <- tmp$sub_index
+  internal  <- tmp$internal
+  
+  
+  sub_functions <-
+    mapply(function(i, s) {
+      lapply(seq_len(nrow(s)), function(t) i[s[t, 1]:s[t, 2]])
+    },
+    internal, sub_index, SIMPLIFY = FALSE)
+  sub_functions <- do.call("c", sub_functions)
+  
+  # folder for sub_functions
+  folder_index <- which(names(main_functions) %in% names(sub_index))
+  # folder_sub <- rep(folder_main[folder_index], sapply(sub_index, nrow))
+  
+  snet_minor_info("Found {length(sub_functions)} sub-functions")
+  
+  def_sub_functions <-
+    unlist(lapply(seq_along(sub_functions),
+                  function(x) sub_functions[[x]][1]))
+  
+  
+  if (!is.null(def_sub_functions)) {
+    names(sub_functions) <-
+      unlist(gsub(" ", "",
+                  lapply(base::strsplit(def_sub_functions, "<-"), "[[", 1)))
+  }
+  
+  
+  # combine sub to all functions
+  all_functions <- c(main_functions, sub_functions)
+  # all_folder <- folder_main
+  # all_folder    <- c(folder_main, folder_sub)
+  snet_minor_info("Found {length(all_functions)} functions")
+  
+  # remove duplicates
+  index <- !duplicated(all_functions)
+  all_functions <- all_functions[index]
+  # all_folder    <-  all_folder[index]
+  snet_minor_info("{sum(!index)} duplicated functions")
+  
+  dup_names <- duplicated(names(all_functions))
+  if (any(dup_names)) {
+    warning(paste0("multiple function: ",
+                   paste0(unique(names(all_functions)[dup_names]),
+                          collapse = ", "),
+                   " Using only the first!"))
+    all_functions <- all_functions[!dup_names]
+    # all_folder    <- all_folder[!dup_names]
+  }
+  
+  # remove sub_functions from functions
+  tmp <- getsubindex(funlist = all_functions,
+                     variations = variations)
+  
+  for (i_name in names(tmp$sub_index)) {
+    i_num <- which(names(all_functions) == i_name)
+    s <- tmp$sub_index[[i_name]]
+    if (nrow(s) == 0) next
+    remove_index <- unique(unlist(sapply(seq_len(nrow(s)),
+                                         function(t) s[t, 1]:s[t, 2])))
+    all_functions[[i_num]][remove_index] <- ""
+  }
+  
+  # remove empty lines
+  all_functions <- lapply(all_functions, function(x) x[x != ""])
+  
+  # combine sub to all functions
+  all_files  <- c(all_functions, scripts)
+  # all_folder <- c(all_folder, folder_scripts)
+  snet_minor_info("Found {length(all_files)} files")
+
+  # check if there are functions
+  if (length(all_files) == 0) {
+    warning("no functions found")
+    return(list(matrix = NULL, igraph = NULL))
+  }
+  
+  # get number of line per function
+  lines <- sapply(all_files, length)
+  
+  # update function definition
+  def_function_index <-
+    lapply(
+      all_files,
+      function(x) {
+        unique(unlist(
+          lapply(variations,
+                 function(y) which(grepl(pattern = y, x))))
+        )
+      }
+    )
+  
+  def_functions <- lapply(
+    seq_along(all_files),
+    function(x) all_files[[x]][def_function_index[[x]]]
+  )
+  tmp_def_idx <- sapply(def_functions, function(x) length(x) == 0)
+  def_functions[tmp_def_idx] <- ""
+  
+  
+  def_functions[!tmp_def_idx] <- gsub(
+    pattern = " ",
+    replacement = "",
+    lapply(base::strsplit(unlist(def_functions[!tmp_def_idx]), "<-"), "[[", 1))
+  
+  tmp_def_idx2 <- def_functions == "" & !tmp_def_idx
+  # check for empty entries
+  if (any(tmp_def_idx2)) {
+    warning(paste0("Missing function name. ",
+                   "This would have led to missleading plots. ",
+                   "Removed from script(s): '",
+                   paste0(names(all_files)[tmp_def_idx2],
+                          collapse = "', '"), "'"))
+  }
+  def_functions <- unique(unlist(
+    def_functions[def_functions != "" & !tmp_def_idx]
+  ))
+  
+  
+  
+  # used for later adjustments of the network matrix
+  def_functions2 <-
+    lapply(seq_along(all_files),
+           function(x) all_files[[x]][def_function_index[[x]]])
+  
+  # check for non characters
+  def_functions2 <-
+    lapply(def_functions2, function(x) {
+      if (is.character(x)) {
+        x
+      } else {
+        character(0)
+      }
+    })
+  
+  
+  def_functions2 <-
+    lapply(def_functions2,
+           function(x) {
+             gsub(" ", "", sapply(base::strsplit(x, "<-"), "[[", 1))
+           }
+    )
+  
+  def_functions2 <-
+    lapply(seq_along(def_functions2),
+           function(x) {
+             ifelse(length(def_functions2[[x]]) == 0,
+                    names(all_files)[x],
+                    def_functions2[[x]])
+           }
+    )
+  
+  # remove function definition
+  keep_lines <- mapply(function(x, y) which(!1:y %in% x),
+                       def_function_index, lapply(all_files, length),
+                       SIMPLIFY = FALSE)
+  
+  
+  clean_functions <- all_files
+  clean_functions <-
+    lapply(seq_along(clean_functions),
+           function(x) clean_functions[[x]][keep_lines[[x]]])
+  names(clean_functions) <- names(all_files)
+  snet_minor_info("Check length: {length(clean_functions)} clean_functions")
+
+  # remove duplicated names
+  dub_rows <- !duplicated(names(clean_functions))
+  if (!all(dub_rows)) {
+    warning(paste0("Removing duplicates: ",
+                   paste0(names(clean_functions)[!dub_rows], collapse = ", ")))
+    clean_functions <- clean_functions[dub_rows]
+    lines <- lines[dub_rows]
+    # all_folder <- all_folder[dub_rows]
+    def_functions2 <- def_functions2[dub_rows]
+  }
+  
+  # create adjacency matrix: network
+  network <-
+    lapply(clean_functions,
+           function(z) {
+             sapply(paste0(def_functions), #, "\\("
+                    function(x, y = z) sum(grepl(x, y), na.rm = TRUE))
+           })
+  
+  network <- as.data.frame(do.call(rbind, network))
+  snet_minor_info("Initial network has {nrow(network)} rows and {ncol(network)} cols")
+
+  # adjust networks rows and columns
+  names(network) <- gsub("\\\\\\(", "", names(network))
+  new_columns <- rownames(network)[
+    which(!rownames(network) %in% colnames(network))]
+  new_rows <- colnames(network)[
+    which(!colnames(network) %in% rownames(network))]
+  network[, new_columns] <- 0
+  network[new_rows, ] <- 0
+  network <- network[rownames(network)]
+  snet_minor_info("Adding {length(new_rows)} new rows and {length(new_columns)} new cols")
+  snet_minor_info("Adjusted network has {nrow(network)} rows and {ncol(network)} cols")
+
+  # adjust lines, folders
+  old_names <- names(lines)
+  lines <- c(lines, rep(0, length(new_rows)))
+  names(lines) <- c(old_names, new_rows)
+  snet_minor_info("Check length: {length(lines)} lines")
+  
+  # remove duplicated functions within def_functions2
+  if (sum(duplicated(def_functions2)) > 0) {
+    snet_minor_info("There are {sum(duplicated(def_functions2))} inner functions with the same name. Keeping only the first.")
+  }
+  
+  tmp_index <- unlist(lapply(
+    new_rows,
+    function(y) {
+      which(lapply(def_functions2, function(x) x == y) == TRUE)[1]
+    }
+  ))
+  if (length(tmp_index) == 0) {
+    tmp_index <- NULL
+  }
+  
+  # all_folder <- c(all_folder, all_folder[tmp_index])
+  # snet_minor_info("check length: {length(all_folder)} all_folder")
+  
+  # simplify - removing functions with no connections ####
+  # if (simplify) {
+  #   calls <- apply(1, X = network, FUN = sum) + apply(2, X = network, FUN = sum)
+  #   keep <- which(calls != 0)
+  #   network <- network[keep, keep]
+  #   all_folder <- all_folder[keep]
+  #   lines <- lines[keep]
+  # }
+  
+  # create igraph
+  g1 <- igraph::graph_from_adjacency_matrix(
+    as.matrix(network),
+    mode = c("directed"),
+    weighted = TRUE,
+    diag = TRUE,
+    add.colnames = NULL,
+    add.rownames = NA)
+  
+  igraph::V(g1)$label <- names(lines)
+  igraph::V(g1)$lines <- lines
+  # igraph::V(g1)$folder <- all_folder
+  # igraph::V(g1)$color  <- as.numeric(as.factor(all_folder))
+  
+  # output
+  return(as_tidygraph(g1))
+}
\ No newline at end of file
