@@ -31,10 +31,21 @@
 #' net_upperbound(ison_networkers)
 NULL
 
+#' @rdname measure_hierarchy 
+#' @export
+net_by_hierarchy <- function(.data){
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
+  out <- data.frame(Connectedness = net_connectedness(.data),
+                    InvReciprocity = 1 - net_reciprocity(.data),
+                    Efficiency = net_efficiency(.data),
+                    LeastUpperBound = net_upperbound(.data))
+  make_network_motif(out, .data)
+}
+
 #' @rdname measure_hierarchy 
 #' @export
 net_connectedness <- function(.data){
-  if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
   dists <- igraph::distances(as_igraph(.data))
   make_network_measure(1 - sum(dists==Inf)/sum(dists!=0),
                        .data, 
@@ -44,7 +55,7 @@ net_connectedness <- function(.data){
 #' @rdname measure_hierarchy 
 #' @export
 net_efficiency <- function(.data) {
-  if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
   degs <- node_indegree(.data, normalized = FALSE)
   out <- (net_nodes(.data)-1)/sum(degs)
   make_network_measure(out, .data, 
@@ -54,7 +65,7 @@ net_efficiency <- function(.data) {
 #' @rdname measure_hierarchy 
 #' @export
 net_upperbound <- function(.data) {
-  if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
   dists <- igraph::distances(.data, mode = "in")
   dists[is.infinite(dists)] <- 0
   dists <- dists[order(rowSums(dists)), order(rowSums(dists))]
